import network
import time
import webrepl

def do_connect():
    wifi_ssid = "Esp32AccessPoint"
    wifi_password = "12345678" 
    station = network.WLAN(network.AP_IF)
    station.active(True)
    while station.active() == False:
        print("Connecting...")
        time.sleep(3)
    print("Connected!")
    print("My IP Address:", station.ifconfig()[0])
if __name__ == "__main__":
    do_connect()
    webrepl.start()


from machine import Pin, time_pulse_us
from utime import sleep_us

class HCSR04:
    """
    Driver to use the untrasonic sensor HC-SR04.
    The sensor range is between 2cm and 4m.

    The timeouts received listening to echo pin are converted to OSError('Out of range')

    """
    # echo_timeout_us is based in chip range limit (400cm)
    def __init__(self, trigger_pin, echo_pin, echo_timeout_us=500*2*30):
        """
        trigger_pin: Output pin to send pulses
        echo_pin: Readonly pin to measure the distance. The pin should be protected with 1k resistor
        echo_timeout_us: Timeout in microseconds to listen to echo pin. 
        By default is based in sensor limit range (4m)
        """
        self.echo_timeout_us = echo_timeout_us
        # Init trigger pin (out)
        self.trigger = Pin(trigger_pin, mode=Pin.OUT, pull=None)
        self.trigger.value(0)

        # Init echo pin (in)
        self.echo = Pin(echo_pin, mode=Pin.IN, pull=None)

    def _send_pulse_and_wait(self):
        """
        Send the pulse to trigger and listen on echo pin.
        We use the method `machine.time_pulse_us()` to get the microseconds until the echo is received.
        """
        self.trigger.value(0) # Stabilize the sensor
        sleep_us(5)
        self.trigger.value(1)
        # Send a 10us pulse.
        sleep_us(10)
        self.trigger.value(0)
        try:
            pulse_time = time_pulse_us(self.echo, 1, self.echo_timeout_us)
            # time_pulse_us returns -2 if there was timeout waiting for condition; and -1 if there was timeout during the main measurement. It DOES NOT raise an exception
            # ...as of MicroPython 1.17: http://docs.micropython.org/en/v1.17/library/machine.html#machine.time_pulse_us
            if pulse_time < 0:
                MAX_RANGE_IN_CM = const(500) # it's really ~400 but I've read people say they see it working up to ~460
                pulse_time = int(MAX_RANGE_IN_CM * 29.1) # 1cm each 29.1us
            return pulse_time
        except OSError as ex:
            if ex.args[0] == 110: # 110 = ETIMEDOUT
                raise OSError('Out of range')
            raise ex

    def distance_mm(self):
        """
        Get the distance in milimeters without floating point operations.
        """
        pulse_time = self._send_pulse_and_wait()

        # To calculate the distance we get the pulse_time and divide it by 2 
        # (the pulse walk the distance twice) and by 29.1 becasue
        # the sound speed on air (343.2 m/s), that It's equivalent to
        # 0.34320 mm/us that is 1mm each 2.91us
        # pulse_time // 2 // 2.91 -> pulse_time // 5.82 -> pulse_time * 100 // 582 
        mm = pulse_time * 100 // 582
        return mm

    def distance_cm(self):
        """
        Get the distance in centimeters with floating point operations.
        It returns a float
        """
        pulse_time = self._send_pulse_and_wait()

        # To calculate the distance we get the pulse_time and divide it by 2 
        # (the pulse walk the distance twice) and by 29.1 becasue
        # the sound speed on air (343.2 m/s), that It's equivalent to
        # 0.034320 cm/us that is 1cm each 29.1us
        cms = (pulse_time / 2) / 29.1
        return cms


from machine import Pin
from time import sleep

class KeypadException(Exception):
    """
    Exception class for keypad-related errors.
    """
    pass

class Keypad:
    def __init__(self, row_pins, column_pins, keys):
        """
        Initialize the keypad object.

        Args:
            row_pins (list): List of row pins.
            column_pins (list): List of column pins.
            keys (list): 2D list representing the key layout.

        Raises:
            KeypadException: If pins or keys are not properly defined.
        """
        if not all(isinstance(pin, Pin) for pin in row_pins):
            raise KeypadException("Row pins must be instances of Pin.")
        
        if not all(isinstance(pin, Pin) for pin in column_pins):
            raise KeypadException("Column pins must be instances of Pin.")
        
        if not isinstance(keys, list) or not all(isinstance(row, list) for row in keys):
            raise KeypadException("Keys must be a 2D list.")

        self.row_pins = row_pins
        self.column_pins = column_pins
        self.keys = keys

        for pin in self.row_pins:
            pin.init(Pin.IN, Pin.PULL_UP)

        for pin in self.column_pins:
            pin.init(Pin.OUT)

        if len(self.row_pins) != len(self.keys) or len(self.column_pins) != len(self.keys[0]):
            raise KeypadException("Number of row/column pins does not match the key layout size.")

    def read_keypad(self):
        """
        Read the keypad and return the pressed key.

        Returns:
            str or None: Pressed key or None if no key is pressed.

        Raises:
            KeypadException: If pins or keys are not properly defined.
        """
        if not self.column_pins:
            raise KeypadException("No column pins defined.")
        
        if not self.row_pins:
            raise KeypadException("No row pins defined.")
        
        if not self.keys:
            raise KeypadException("No key layout defined.")

        for col_pin in self.column_pins:
            col_pin.value(0)  # Set column pin to LOW
            for i, row_pin in enumerate(self.row_pins):
                if not row_pin.value():  # If row pin reads LOW
                    key_pressed = self.keys[i][self.column_pins.index(col_pin)]
                    col_pin.value(1)  # Set column pin back to HIGH
                    return key_pressed
            col_pin.value(1)  # Set column pin back to HIGH
        return None  # Return None if no key is pressed


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="innov8r",
    version="6.0.2",
    author="Shivkumar Chauhan",
    author_email="sksinghat95@gmail.com",
    description="Python-based GUI application designed to streamline software development workflows with innovative tools and utilities. It provides developers with an intuitive and user-friendly interface for building efficient and scalable solutions",
    long_description=long_description,
    include_package_data=True,
        package_data={
        'innov8r': [
            'res/*',
            'res/*',
            'res/*/*',
            'res/*/*/*',
            'res/*/*/*/*',
            'plugins/*',
            'plugins/*/*',
            'plugins/*/*/*',
            'plugins/*/*/*/*',
            "locales/*",
            "locales/*/*",
            "locales/*/*/*",
            "locales/*/*/*/*",
            "dbus/*",
            "vendored_libs/*",
            "vendored_libs/*/*",
            "vendored_libs/*/*/*"
        ]
    },
    install_requires=[
        "esptool",
        "pyserial",
        "pyqt5",
        "pyqt5-tools",
        "flask",
        "flask-cors",
        "pillow",
        "requests",
        "Send2Trash",
        "asttokens",
        "mypy",
        "docutils",
        "pylint",
        "jedi"
    ],
    long_description_content_type="text/markdown",
    url="https://github.com/TechForEverybody/Innov8r-IDE",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)